multidim.PointCloud.gaussian_fit — GDA Toolbox v1.0 Manual

# multidim.PointCloud.gaussian_fit

`PointCloud.` `gaussian_fit`(center=None)

  Fit a normalized Gaussian to this cloud (using SVD).

  Parameters: | center If center is None (default), we find the best Gaussian with free mean. If center is given as an integer, use the point with that integer as the mean of the Gaussian. If center is given as a tuple or array, use that coordinate point as the mean of the Gaussian.
  Returns: | (mean, sigma, rotation) for the Gaussian, suitable for `gaussian`

#### Previous topic

multidim.PointCloud.from_multisample_multilabel

#### Next topic

multidim.PointCloud.make_pers0